@@ -64,25 +64,10 @@ const char *plugin_version="LiVES flv decoder version 1.1";
 #include <pthread.h>
 
 #include "decplugin.h"
+#include "libav_helper.h"
+
 #include "flv_decoder.h"
 
-
-#if (LIBAVCODEC_VERSION_MAJOR > 54)
-#define CodecID AVCodecID
-#define CODEC_ID_NONE AV_CODEC_ID_NONE
-#define CODEC_ID_FLV1 AV_CODEC_ID_FLV1
-#define CODEC_ID_FLASHSV AV_CODEC_ID_FLASHSV
-#define CODEC_ID_FLASHSV2 AV_CODEC_ID_FLASHSV2
-#define CODEC_ID_VP6A AV_CODEC_ID_VP6A
-#define CODEC_ID_VP6F AV_CODEC_ID_VP6F
-#define CODEC_ID_H264 AV_CODEC_ID_H264
-#endif
-
-#if !HAVE_AVCODEC_OPEN2
-#define avcodec_open2(a, b, c) avcodec_open(a, b)
-#endif
-
-
 static index_container_t **indices;
 static int nidxc;
 static pthread_mutex_t indices_mutex;
@@ -1294,9 +1279,13 @@ static boolean attach_stream(lives_clip_data_t *cdata, boolean isclone) {
     if (ofd!=-1) {
       int res;
       snprintf(cmd,1024,"LANGUAGE=en LANG=en mplayer \"%s\" -identify -frames 0 2>/dev/null | grep ID_VIDEO_FPS > %s",cdata->URI,tmpfname);
-      
       res=system(cmd);
-      
+
+      if (res) {
+	snprintf(cmd,1024,"LANGUAGE=en LANG=en mplayer2 \"%s\" -identify -frames 0 2>/dev/null | grep ID_VIDEO_FPS > %s",cdata->URI,tmpfname);
+	res=system(cmd);
+      }
+
       if (!res) {
 	char buffer[1024];
 	ssize_t bytes=read(ofd,buffer,1024);
