@@ -70,54 +70,14 @@ const char *plugin_version="LiVES mkv decoder version 1.2";
 
 #include "decplugin.h"
 
-#include <libavutil/intfloat_readwrite.h>
 #include <libavutil/intreadwrite.h>
 #include <libavutil/lzo.h>
 #include <libavutil/dict.h>
 
 
-#if (LIBAVCODEC_VERSION_MAJOR > 54)
-#define CodecID AVCodecID
-#define CODEC_ID_NONE AV_CODEC_ID_NONE
-#define CODEC_ID_TEXT AV_CODEC_ID_TEXT
-#define CODEC_ID_SSA AV_CODEC_ID_SSA
-#define CODEC_ID_VP8 AV_CODEC_ID_VP8
-#define CODEC_ID_THEORA AV_CODEC_ID_THEORA
-#define CODEC_ID_SNOW AV_CODEC_ID_SNOW
-#define CODEC_ID_DIRAC AV_CODEC_ID_DIRAC
-#define CODEC_ID_MJPEG AV_CODEC_ID_MJPEG
-#define CODEC_ID_MPEG1VIDEO AV_CODEC_ID_MPEG1VIDEO
-#define CODEC_ID_MPEG2VIDEO AV_CODEC_ID_MPEG2VIDEO
-#define CODEC_ID_MPEG4 AV_CODEC_ID_MPEG4
-#define CODEC_ID_H264 AV_CODEC_ID_H264
-#define CODEC_ID_MSMPEG4V3 AV_CODEC_ID_MSMPEG4V3
-#define CODEC_ID_RV10 AV_CODEC_ID_RV10
-#define CODEC_ID_RV20 AV_CODEC_ID_RV20
-#define CODEC_ID_RV30 AV_CODEC_ID_RV30
-#define CODEC_ID_RV40 AV_CODEC_ID_RV40
-#define CODEC_ID_RAWVIDEO AV_CODEC_ID_RAWVIDEO
-#endif
-
-
-#if !HAVE_AVCODEC_OPEN2
-#define avcodec_open2(a, b, c) avcodec_open(a, b)
-#endif
-
-#if !HAVE_AVCODEC_ALLOC_CONTEXT3
-#define avcodec_alloc_context3(a) avcodec_alloc_context()
-#endif
-
-#if HAVE_AVFORMAT_NEW_STREAM
-#define av_new_stream(a, b) avformat_new_stream(a, NULL)
-#endif
-
-#if HAVE_AVPRIV_SET_PTS_INFO
-#define av_set_pts_info(a,b,c,d) avpriv_set_pts_info(a,b,c,d)
-#endif
-
-
 #include "mkv_decoder.h"
 
+#include "libav_helper.h"
 
 #if CONFIG_ZLIB
 #include <zlib.h>
@@ -133,6 +93,17 @@ static pthread_mutex_t indices_mutex;
 
 ////////////////////////////////////////////////////////////////////////////
 
+static double lives_int2dbl(int64_t v) {
+    if((uint64_t)v+v > 0xFFEULL<<52)
+        return NAN;
+    return ldexp(((v&((1LL<<52)-1)) + (1LL<<52)) * (v>>63|1), (v>>52&0x7FF)-1075);
+}
+
+static float lives_int2flt(int32_t v) {
+    if((uint32_t)v+v > 0xFF000000U)
+        return NAN;
+    return ldexp(((v&0x7FFFFF) + (1<<23)) * (v>>31|1), (v>>23&0xFF)-150);
+}
 
 const uint8_t ff_log2_tab[256]={
   0,0,1,1,2,2,2,2,3,3,3,3,3,3,3,3,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,
@@ -368,7 +339,7 @@ static int ebml_read_float(const lives_clip_data_t *cdata, int size, double *num
 
     val32 = AV_RB32(buffer);
 
-    *num= av_int2flt(val32);
+    *num= lives_int2flt(val32);
 
   } else if(size==8){
 
@@ -383,7 +354,7 @@ static int ebml_read_float(const lives_clip_data_t *cdata, int size, double *num
 
     val64 = AV_RB64(buffer);
 
-    *num= av_int2dbl(val64);
+    *num= lives_int2dbl(val64);
   } else {
     errval=ERR_INVALID_DATA;
     return -errval;
