@@ -9,6 +9,7 @@
 #include "main.h"
 #include "callbacks.h"
 #include "support.h"
+#include "effects.h"
 #include "effects-weed.h"
 
 #define afile mainw->files[pulsed->playing_file]
@@ -86,9 +87,15 @@ boolean lives_pulse_init (short startup_phase) {
 	do_error_dialog_with_check(_("\nUnable to connect to pulse audio server.\nFalling back to sox audio player.\nYou can change this in Preferences/Playback.\n"),WARN_MASK_NO_PULSE_CONNECT);
 	switch_aud_to_sox(prefs->warning_mask&WARN_MASK_NO_PULSE_CONNECT);
       }
-      else if (startup_phase==0&&capable->has_mplayer) {
-	do_error_dialog_with_check(_("\nUnable to connect to pulse audio server.\nFalling back to mplayer audio player.\nYou can change this in Preferences/Playback.\n"),WARN_MASK_NO_PULSE_CONNECT);
-	switch_aud_to_mplayer(prefs->warning_mask&WARN_MASK_NO_PULSE_CONNECT);
+      else if (startup_phase==0) {
+	if (capable->has_mplayer) {
+	  do_error_dialog_with_check(_("\nUnable to connect to pulse audio server.\nFalling back to mplayer audio player.\nYou can change this in Preferences/Playback.\n"),WARN_MASK_NO_PULSE_CONNECT);
+	  switch_aud_to_mplayer(prefs->warning_mask&WARN_MASK_NO_PULSE_CONNECT);
+	}
+	else if (capable->has_mplayer2) {
+	  do_error_dialog_with_check(_("\nUnable to connect to pulse audio server.\nFalling back to mplayer2 audio player.\nYou can change this in Preferences/Playback.\n"),WARN_MASK_NO_PULSE_CONNECT);
+	  switch_aud_to_mplayer2(prefs->warning_mask&WARN_MASK_NO_PULSE_CONNECT);
+	}
       }
       else {
 	msg=g_strdup(_("\nUnable to connect to pulse audio server.\n"));
@@ -275,7 +282,7 @@ static void pulse_audio_write_process (pa_stream *pstream, size_t nbytes, void *
      gfloat shrink_factor=1.f;
      int swap_sign;
 
-     file *xfile=afile;
+     lives_clip_t *xfile=afile;
 
  #ifdef DEBUG_PULSE
      g_printerr("playing... pulseFramesAvailable = %ld\n", pulseFramesAvailable);
@@ -512,7 +519,7 @@ static void pulse_audio_write_process (pa_stream *pstream, size_t nbytes, void *
 	     }
 	   }
 
-	   if (has_audio_filters(FALSE)&&(pulsed->playing_file!=mainw->ascrap_file)) {
+	   if (has_audio_filters(AF_TYPE_ANY)&&(pulsed->playing_file!=mainw->ascrap_file)) {
 	     boolean memok=TRUE;
 	     float **fltbuf=(float **)g_malloc(pulsed->out_achans*sizeof(float *));
 	     register int i;
@@ -589,7 +596,7 @@ static void pulse_audio_write_process (pa_stream *pstream, size_t nbytes, void *
 	     pulsed->sound_buffer=(guchar *)pulsed->aPlayPtr->data;
 	     buf=(void *)pulsed->sound_buffer;
 
-	     if (has_audio_filters(FALSE)) {
+	     if (has_audio_filters(AF_TYPE_ANY)) {
 	       register int i;
 
 	       memok=TRUE;
@@ -747,7 +754,7 @@ size_t pulse_flush_read_data(pulse_driver_t *pulsed, int fileno, size_t rbytes,
   float out_scale;
   int swap_sign;
 
-  file *ofile;
+  lives_clip_t *ofile;
 
 
   if (mainw->agen_key==0&&!mainw->agen_needs_reinit) {
@@ -861,7 +868,7 @@ static void pulse_audio_read_process (pa_stream *pstream, size_t nbytes, void *a
     // in this case we read external audio, but maybe not record it
     // we may wish to analyse the audio for example
 
-    if (has_audio_filters(TRUE)) {
+    if (has_audio_filters(AF_TYPE_A)) {
       // convert to float, apply any analysers
       boolean memok=TRUE;
       float **fltbuf=(float **)g_malloc(pulsed->in_achans*sizeof(float *));
@@ -1332,7 +1339,7 @@ void pulse_aud_pb_ready(int fileno) {
   // - check if we need to reconnect
   // - set vals
   gchar *tmpfilename=NULL;
-  file *sfile=mainw->files[fileno];
+  lives_clip_t *sfile=mainw->files[fileno];
   int asigned=!(sfile->signed_endian&AFORM_UNSIGNED);
   int aendian=!(sfile->signed_endian&AFORM_BIG_ENDIAN);
 
